@@ -8,11 +8,11 @@ use Moose::Role;
 use namespace::autoclean;
 
 use Encode;
-use HTML::Tidy;
+use HTML::T5;
 
 =head1 NAME
 
-Perlanet::Trait::Tidy - run posts through HTML::Tidy
+Perlanet::Trait::Tidy - run posts through HTML::T5 (an HTML::Tidy replacement)
 
 =head1 SYNOPSIS
 
@@ -25,18 +25,18 @@ Perlanet::Trait::Tidy - run posts through HTML::Tidy
 =head1 DESCRIPTION
 
 Before a post is added to the aggregated feed, it will be run through
-HTML::Tidy.
+HTML::T5.
 
 =head2 Configuring
 
-To configure the HTML::Tidy instance, you should override the C<_build_tidy>
-method. This method takes no input, and returns a HTML::Tidy instance.
+To configure the HTML::T5 instance, you should override the C<_build_tidy>
+method. This method takes no input, and returns a HTML::T5 instance.
 
 =head1 ATTRIBUTES
 
 =head2 tidy
 
-An instance of L<HTML::Tidy> used to tidy the feed entry contents
+An instance of L<HTML::T5> used to tidy the feed entry contents
 before outputting. For default settings see source..
 
 =cut
@@ -61,7 +61,7 @@ sub _build_tidy {
     show_warnings     => 0,
   );
 
-  my $tidy = HTML::Tidy->new(\%tidy);
+  my $tidy = HTML::T5->new(\%tidy);
   $tidy->ignore( type => TIDY_WARNING );
 
   return $tidy;
@@ -86,10 +86,11 @@ around 'clean_html' => sub {
 =head1 AUTHOR
 
 Oliver Charles, <oliver.g.charles@googlemail.com>
+Dave Cross, <dave@perlhacks.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2010 by Magnum Solutions Ltd.
+Copyright (c) 2010-2023 by Magnum Solutions Ltd.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
